#[non_exhaustive]pub enum Blend {
Over,
Source,
}Expand description
How the source is combined with the backdrop.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Over
Porter-Duff source-over: the source is drawn on top of the backdrop.
The source replaces the backdrop entirely within its rectangle.